# INFO

Just a tiny docker container used to extract the necessary parts of ``boost`` with the use of the tool ``bcp``

To run: ``docker-compose up --build``

The output will be a ``.tar.xz`` file in this folder with the bits and pieces needed to include.